Classes and methods
===================

Svgis is primarily built as a command line tool, but it has full
API customization.

.. toctree::
   :maxdepth: 2

   svgis
   svg
   draw
   style
   bounding

